==> aws-cdk-scala_2.12-0.21.0-sources.jar: io/burkard/cdk/services/kinesisanalyticsv2/cfnApplication/ApplicationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisanalyticsv2.cfnApplication

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ApplicationConfigurationProperty {

  def apply(
    applicationCodeConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationCodeConfigurationProperty] = None,
    zeppelinApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ZeppelinApplicationConfigurationProperty] = None,
    sqlApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.SqlApplicationConfigurationProperty] = None,
    environmentProperties: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.EnvironmentPropertiesProperty] = None,
    applicationSnapshotConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationSnapshotConfigurationProperty] = None,
    flinkApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.FlinkApplicationConfigurationProperty] = None
  ): software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationConfigurationProperty.Builder)
      .applicationCodeConfiguration(applicationCodeConfiguration.orNull)
      .zeppelinApplicationConfiguration(zeppelinApplicationConfiguration.orNull)
      .sqlApplicationConfiguration(sqlApplicationConfiguration.orNull)
      .environmentProperties(environmentProperties.orNull)
      .applicationSnapshotConfiguration(applicationSnapshotConfiguration.orNull)
      .flinkApplicationConfiguration(flinkApplicationConfiguration.orNull)
      .build()
}

==> aws-cdk-scala_3-0.22.0-sources.jar: io/burkard/cdk/services/kinesisanalyticsv2/cfnApplication/ApplicationConfigurationProperty.scala <==
package io.burkard.cdk.services.kinesisanalyticsv2.cfnApplication

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object ApplicationConfigurationProperty {

  def apply(
    applicationCodeConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationCodeConfigurationProperty] = None,
    zeppelinApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ZeppelinApplicationConfigurationProperty] = None,
    sqlApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.SqlApplicationConfigurationProperty] = None,
    environmentProperties: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.EnvironmentPropertiesProperty] = None,
    applicationSnapshotConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationSnapshotConfigurationProperty] = None,
    vpcConfigurations: Option[List[_]] = None,
    flinkApplicationConfiguration: Option[software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.FlinkApplicationConfigurationProperty] = None
  ): software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationConfigurationProperty =
    (new software.amazon.awscdk.services.kinesisanalyticsv2.CfnApplication.ApplicationConfigurationProperty.Builder)
      .applicationCodeConfiguration(applicationCodeConfiguration.orNull)
      .zeppelinApplicationConfiguration(zeppelinApplicationConfiguration.orNull)
      .sqlApplicationConfiguration(sqlApplicationConfiguration.orNull)
      .environmentProperties(environmentProperties.orNull)
      .applicationSnapshotConfiguration(applicationSnapshotConfiguration.orNull)
      .vpcConfigurations(vpcConfigurations.map(_.asJava).orNull)
      .flinkApplicationConfiguration(flinkApplicationConfiguration.orNull)
      .build()
}
